==> haskell-uuid-1.3.11-4-armv7h.pkg.tar.xz: usr/share/haskell/haskell-uuid/register.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: uuid
version: 1.3.11
id: uuid-1.3.11-2384b4b106c65c88cadd3d543d7564df
key: uuid_9mmywgKhvj5FiBgHHa8L6v
license: BSD3
copyright: (c) 2008-2014 Antoine Latter
maintainer: aslatter@gmail.com
homepage: https://github.com/aslatter/uuid
synopsis: For creating, comparing, parsing and printing Universally Unique Identifiers
description:
    This library is useful for creating, comparing, parsing and
    printing Universally Unique Identifiers.
    See <http://en.wikipedia.org/wiki/UUID> for the general idea.
category: Data
author: Antoine Latter
exposed: True
exposed-modules:
    Data.UUID Data.UUID.Util Data.UUID.V1 Data.UUID.V3 Data.UUID.V4
    Data.UUID.V5
hidden-modules: Data.UUID.Named Data.Word.Util
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/uuid-1.3.11
library-dirs: /usr/lib/ghc-7.10.3/site-local/uuid-1.3.11
data-dir: /usr/share/arm-linux-ghc-7.10.3/uuid-1.3.11
hs-libraries: HSuuid-1.3.11-9mmywgKhvj5FiBgHHa8L6v
depends:
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    binary-0.7.5.0-29f7044fa0b12dc5c2dcec897db5c464
    bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
    cryptohash-0.11.6-e28406db011dea16e99b7bc1708b91dc
    network-info-0.2.0.8-bc6c8aa48b93ac2c06aa2e5c4fa39eb6
    random-1.1-41a0a7ecd483c665a5c3a093a5be2968
    text-1.2.2.0-2f82ea4adfdd656d9a8840ad2ee17cc0
    time-1.5.0.1-cf94b0d806e26f6c4e356671290061b2
    uuid-types-1.0.2-e80dd8ed3b7ffef1dd40876281d96804
haddock-interfaces: /usr/share/doc/haskell-uuid/html/uuid.haddock
haddock-html: /usr/share/doc/haskell-uuid/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"

==> haskell-uuid-1.3.11-5-armv7h.pkg.tar.xz: usr/share/haskell/haskell-uuid/register.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: uuid
version: 1.3.11
id: uuid-1.3.11-95935b0432cec422536cd2e31dafa5cb
key: uuid_930MG7FU4Nb13YdLyqXYHj
license: BSD3
copyright: (c) 2008-2014 Antoine Latter
maintainer: aslatter@gmail.com
homepage: https://github.com/aslatter/uuid
synopsis: For creating, comparing, parsing and printing Universally Unique Identifiers
description:
    This library is useful for creating, comparing, parsing and
    printing Universally Unique Identifiers.
    See <http://en.wikipedia.org/wiki/UUID> for the general idea.
category: Data
author: Antoine Latter
exposed: True
exposed-modules:
    Data.UUID Data.UUID.Util Data.UUID.V1 Data.UUID.V3 Data.UUID.V4
    Data.UUID.V5
hidden-modules: Data.UUID.Named Data.Word.Util
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/uuid-1.3.11
library-dirs: /usr/lib/ghc-7.10.3/site-local/uuid-1.3.11
data-dir: /usr/share/arm-linux-ghc-7.10.3/uuid-1.3.11
hs-libraries: HSuuid-1.3.11-930MG7FU4Nb13YdLyqXYHj
depends:
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    binary-0.7.5.0-29f7044fa0b12dc5c2dcec897db5c464
    bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
    cryptohash-0.11.7-d9e0f8e58e69d0717d29fde3802983d0
    network-info-0.2.0.8-bc6c8aa48b93ac2c06aa2e5c4fa39eb6
    random-1.1-41a0a7ecd483c665a5c3a093a5be2968
    text-1.2.2.0-2f82ea4adfdd656d9a8840ad2ee17cc0
    time-1.5.0.1-cf94b0d806e26f6c4e356671290061b2
    uuid-types-1.0.2-e80dd8ed3b7ffef1dd40876281d96804
haddock-interfaces: /usr/share/doc/haskell-uuid/html/uuid.haddock
haddock-html: /usr/share/doc/haskell-uuid/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
